### Name: gsci.ratio
### Title: Test version! Simultaneous confidence intervals for ratios of
###   linear combinations of parameter estimates
### Aliases: gsci.ratio
### Keywords: htest

### ** Examples


library(mratios)

# A 90-days chronic toxicity assay:
# Which of the doses (groups 2,3,4) do not show a decrease in
# bodyweight more pronounced than 90 percent of the bodyweight
# in the control group?

data(BW)
boxplot(Weight~Dose,data=BW)

lmfit <- lm(Weight~Dose-1, data=BW)
est <- coefficients(lmfit)
vc <- vcov(lmfit)
CMAT <- contrMatRatio(table(BW$Dose), type="Dunnett")

BWnoninf <- gsci.ratio(est, vc, CMAT$numC, CMAT$denC, alternative="greater", degfree=lmfit$df.residual)
BWnoninf
# the same:
sci.ratio(Weight~Dose, data=BW, type="Dunnett", alternative="greater")

# Plot
plot(BWnoninf, rho0=0.9)



#### Mixed Model Example
library(nlme)
data(Milk)
# maybe there are nicer models available
lmefit <- lme(protein ~ Diet-1, data=Milk, random=~Time|Cow, correlation=corAR1(form=~Time|Cow))
estm <- fixef(lmefit)
vcm <- vcov(lmefit)
# all-pair comparisons
CM <- rbind(c(1,0,0),
            c(1,0,0),
            c(0,1,0))
DM <- rbind(c(0,1,0),
            c(0,0,1),
            c(0,0,1))
rownames(CM) <- c("b/b+l", "b/l", "b+l/l")
gscimix <- gsci.ratio(estm, vcm, CM, DM, degfree=anova(lmefit)[,2])
plot(gscimix)



